@@ -84,7 +84,7 @@ static void           docbook_request         (YelpDocument        *document,
 					       gchar               *page_id,
 					       YelpDocumentFunc     func,
 					       gpointer             user_data);
-static gpointer       docbook_get_sections    (YelpDocument        *document);
+/* static gpointer       docbook_get_sections    (YelpDocument        *document); */
 
 /* YelpTransform */
 static void           transform_func          (YelpTransform       *transform,
@@ -227,13 +227,13 @@ yelp_docbook_new (gchar *filename)
 /******************************************************************************/
 /** YelpDocument **************************************************************/
 
-static gpointer
-docbook_get_sections (YelpDocument *document)
-{
-    YelpDocbook *db = (YelpDocbook *) document;
+/* static gpointer */
+/* docbook_get_sections (YelpDocument *document) */
+/* { */
+/*     YelpDocbook *db = (YelpDocbook *) document; */
     
-    return (gpointer) (db->priv->sections);
-}
+/*     return (gpointer) (db->priv->sections); */
+/* } */
 
 static void
 docbook_request (YelpDocument     *document,
@@ -367,11 +367,12 @@ transform_final_func (YelpTransform *transform, YelpDocbook *docbook)
     error = yelp_error_new (_("Page not found"),
 			    _("The requested page was not found in the document %s."),
 			    priv->filename);
-    yelp_document_error_pending (YELP_DOCUMENT (docbook), error);
+    yelp_document_final_pending (YELP_DOCUMENT (docbook), error);
 
     yelp_transform_release (transform);
     priv->transform = NULL;
     priv->transform_running = FALSE;
+    priv->state = DOCBOOK_STATE_PARSED;
 
     if (priv->xmldoc)
 	xmlFreeDoc (priv->xmldoc);
@@ -495,12 +496,15 @@ docbook_process (YelpDocbook *docbook)
 	params_max += 20;
 	params = g_renew (gchar *, params, params_max);
     }
+    params[params_i++] = g_strdup ("db.chunk.max_depth");
+    params[params_i++] = g_strdup_printf ("%i", docbook->priv->max_depth);
 
     params[params_i] = NULL;
 
     yelp_transform_start (priv->transform,
 			  priv->xmldoc,
 			  params);
+    g_strfreev (params);
     g_mutex_unlock (priv->mutex);
 
  done:
@@ -550,16 +554,16 @@ docbook_walk (YelpDocbook *docbook)
 
     id = xmlGetProp (priv->xmlcur, BAD_CAST "id");
 
-    if (docbook_walk_chunkQ (docbook)) {
-	title = BAD_CAST docbook_walk_get_title (docbook);
-
+    if (docbook_walk_divisionQ (docbook) && !id) {
 	/* if id attribute is not present, autogenerate a
 	 * unique value, and insert it into the in-memory tree */
-	if (!id) {
-	    g_snprintf (autoidstr, 20, "_auto-gen-id-%d", ++autoid);
-	    xmlNewProp (priv->xmlcur, BAD_CAST "id", BAD_CAST autoidstr);
-	    id = xmlGetProp (priv->xmlcur, BAD_CAST "id"); 
-	}
+	g_snprintf (autoidstr, 20, "_auto-gen-id-%d", ++autoid);
+	xmlNewProp (priv->xmlcur, BAD_CAST "id", BAD_CAST autoidstr);
+	id = xmlGetProp (priv->xmlcur, BAD_CAST "id"); 
+    }
+
+    if (docbook_walk_chunkQ (docbook)) {
+	title = BAD_CAST docbook_walk_get_title (docbook);
 
 	debug_print (DB_DEBUG, "  id: \"%s\"\n", id);
 	debug_print (DB_DEBUG, "  title: \"%s\"\n", title);
@@ -596,8 +600,7 @@ docbook_walk (YelpDocbook *docbook)
 
     old_cur = priv->xmlcur;
     priv->cur_depth++;
-
-    if (id)
+    if (id && !g_str_equal (id, "x-yelp-index"))
 	yelp_document_add_page_id (document, (gchar *) id, priv->cur_page_id);
 
     for (cur = priv->xmlcur->children; cur; cur = cur->next) {
